"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from acuvity.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PrincipaluserTypedDict(TypedDict):
    r"""Describes the principal information of a user."""

    name: NotRequired[str]
    r"""Identification bit that will be used to identify the origin of the request."""


class Principaluser(BaseModel):
    r"""Describes the principal information of a user."""

    name: Optional[str] = None
    r"""Identification bit that will be used to identify the origin of the request."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from acuvity.types import BaseModel
from typing_extensions import TypedDict


class ModalityTypedDict(TypedDict):
    r"""Represents the modality of a some data."""

    group: str
    r"""The group of data."""
    type: str
    r"""The type of data."""


class Modality(BaseModel):
    r"""Represents the modality of a some data."""

    group: str
    r"""The group of data."""

    type: str
    r"""The type of data."""



# pylint: disable=protected-access

from acuvity import models
from acuvity.apexdiscovery import discover_apex
from acuvity.sdk import Acuvity
from acuvity.types import OptionalNullable, UNSET
from .httpclient import AsyncHttpClient, HttpClient
from .utils.logger import Logger
from .utils.retries import RetryConfig
from typing import Callable, Dict, Optional, Union
import httpx

# Save the original __init__ reference
__original_init__ = Acuvity.__init__

# Define the new __init__ method
def __patched_init__(
    self,
    security: Optional[
        Union[models.Security, Callable[[], models.Security]]
    ] = None,
    apex_domain: Optional[str] = None,
    apex_port: Optional[str] = None,
    server_idx: Optional[int] = None,
    server_url: Optional[str] = None,
    url_params: Optional[Dict[str, str]] = None,
    client: Optional[HttpClient] = None,
    async_client: Optional[AsyncHttpClient] = None,
    retry_config: OptionalNullable[RetryConfig] = UNSET,
    timeout_ms: Optional[int] = None,
    debug_logger: Optional[Logger] = None,
) -> None:
    r"""Instantiates the SDK configuring it with the provided parameters.

    :param security: The security details required for authentication
    :param apex_domain: Allows setting the apex_domain variable for url substitution
    :param apex_port: Allows setting the apex_port variable for url substitution
    :param server_idx: The index of the server to use for all methods
    :param server_url: The server URL to use for all methods
    :param url_params: Parameters to optionally template the server URL with
    :param client: The HTTP client to use for all synchronous methods
    :param async_client: The Async HTTP client to use for all asynchronous methods
    :param retry_config: The retry configuration to use for all supported methods
    :param timeout_ms: Optional request timeout applied to each operation in milliseconds
    """
    if client is None:
        client = httpx.Client()

    assert issubclass(
        type(client), HttpClient
    ), "The provided client must implement the HttpClient protocol."

    apex_domain, apex_port = discover_apex(
        client=client,
        server_url=server_url,
        security=security,
        apex_domain=apex_domain,
        apex_port=apex_port,
    )

    # Call the original __init__ using super
    __original_init__(
        self,
        security=security,
        apex_domain=apex_domain,
        apex_port=apex_port,
        server_idx=server_idx,
        server_url=server_url,
        url_params=url_params,
        client=client,
        async_client=async_client,
        retry_config=retry_config,
        timeout_ms=timeout_ms,
        debug_logger=debug_logger,
    )

# Monkey-patch the __init__
setattr(Acuvity, "__init__", __patched_init__)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .analyzermodel import Analyzermodel, AnalyzermodelTypedDict
from .detector import Detector, DetectorTypedDict
from acuvity.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class AnalyzerTypedDict(TypedDict):
    r"""Represents an analyzer."""

    id: NotRequired[str]
    r"""ID is the identifier of the object."""
    description: NotRequired[str]
    r"""The description of the analyzer."""
    detectors: NotRequired[List[DetectorTypedDict]]
    r"""The detectors the analyzer can use."""
    enabled: NotRequired[bool]
    r"""Tell if the analyzer is enabled by default."""
    group: NotRequired[str]
    r"""The group the analyzer belongs to."""
    models: NotRequired[List[AnalyzermodelTypedDict]]
    r"""The models used by the analyzer."""
    name: NotRequired[str]
    r"""The name of the analyzer."""
    namespace: NotRequired[str]
    r"""The namespace of the object."""
    triggers: NotRequired[List[str]]
    r"""A list of trigger or globl pattern that the analyzer will react on.
    A trigger is the detector Group and Name separated with a /.
    """


class Analyzer(BaseModel):
    r"""Represents an analyzer."""

    id: Annotated[Optional[str], pydantic.Field(alias="ID")] = None
    r"""ID is the identifier of the object."""

    description: Optional[str] = None
    r"""The description of the analyzer."""

    detectors: Optional[List[Detector]] = None
    r"""The detectors the analyzer can use."""

    enabled: Optional[bool] = None
    r"""Tell if the analyzer is enabled by default."""

    group: Optional[str] = None
    r"""The group the analyzer belongs to."""

    models: Optional[List[Analyzermodel]] = None
    r"""The models used by the analyzer."""

    name: Optional[str] = None
    r"""The name of the analyzer."""

    namespace: Optional[str] = None
    r"""The namespace of the object."""

    triggers: Optional[List[str]] = None
    r"""A list of trigger or globl pattern that the analyzer will react on.
    A trigger is the detector Group and Name separated with a /.
    """



import jwt
from urllib.parse import urlparse
from typing import Callable, Optional, Union, Tuple, Any
from .httpclient import HttpClient
from acuvity import models
from acuvity.utils import get_security_from_env
from pydantic import BaseModel

def discover_apex(
    client: HttpClient,
    server_url: Optional[str] = None,
    security: Optional[
        Union[models.Security, Callable[[], models.Security]]
    ] = None,
    apex_domain: Optional[str] = None,
    apex_port: Optional[str] = None,
) -> Tuple[Optional[str], Optional[str]]:
    # pylint: disable=too-many-return-statements
    """
    Discovers the apex domain and port from the token by calling the backend API if the server_url is not provided.
    """
    # if a server_url was given, then we don't need to perform discovery at all
    if server_url is not None:
        return apex_domain, apex_port

    # if an apex_domain was given, then we also don't need to perform discovery
    if apex_domain is not None:
        return apex_domain, apex_port

    # if there is no token, then we can't perform discovery, and yes everything else will fail too
    token: str = ""
    sec: Optional[BaseModel] = get_security_from_env(security, models.Security)
    if sec is None:
        return apex_domain, apex_port
    if not isinstance(sec, models.Security):
        raise ValueError("Security object is not of type Security")
    token = sec.token if sec.token is not None else sec.cookie if sec.cookie is not None else ""
    if token == "":
        return apex_domain, apex_port

    # decode the token but don't verify the signature
    try:
        decoded_token = jwt.decode(token, options={"verify_signature": False})
        if "iss" not in decoded_token:
            raise ValueError("token has no 'iss' field")
    except Exception as e:
        raise ValueError(f"invalid token: {e}") from e

    # extract the API URL from the token
    api_url = decoded_token["iss"]
    if api_url == "":
        raise ValueError("'iss' field value of token is empty, but should have been the API URL")

    def well_known_apex_info(client: HttpClient, token: str, url: str, iteration: int = 0) -> Any:
        if iteration == 3:
            raise ValueError("Too many redirects")
        req = client.build_request("GET", url, headers={"Authorization": f"Bearer {token}"})
        resp = client.send(req, follow_redirects=False) # following redirects automatically will remove the token from the call as headers are not going to be sent anymore
        if resp.is_redirect:
            return well_known_apex_info(client, token, resp.headers["Location"], iteration + 1)
        return resp.json()
    try:
        apex_info = well_known_apex_info(client, token, f"{api_url}/.well-known/acuvity/my-apex.json")
    except Exception as e:
        raise ValueError("Failed to get apex info from well-known endpoint") from e

    try:
        # extract the information from the response
        apex_url = apex_info["url"]
        port = f"{apex_info['port']}"
        # parse the URL to extract the domain
        # use hostname as opposed to netloc because we *only* want the domain, and not the domain:port notation
        parsed_url = urlparse(apex_url)
        domain = parsed_url.hostname
        if port == "":
            raise ValueError("Apex Info: no port in response")
        if domain == "":
            raise ValueError(f"Apex Info: no domain in URL: f{apex_url}")
    except Exception as e:
        raise ValueError("Failed to extract apex info from response") from e

    return domain, port



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from acuvity import models, utils
from acuvity._hooks import HookContext
from acuvity.types import BaseModel, OptionalNullable, UNSET
from acuvity.utils import get_security_from_env
from typing import Any, List, Optional, Union, cast


class Apex(BaseSDK):
    r"""Apex is the proxy and detectiono API service of Acuvity."""

    def list_analyzers(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> List[models.Analyzer]:
        r"""List of all available analyzers.

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if timeout_ms is None:
            timeout_ms = 60000

        if server_url is not None:
            base_url = server_url
        req = self.build_request(
            method="GET",
            path="/_acuvity/analyzers",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 60000, 1.5, 300000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "423", "429", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="get-all-Analyzers",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, List[models.Analyzer])
        if utils.match_response(http_res, ["400", "401", "500"], "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ElementalerrorData)
            raise models.Elementalerror(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def list_analyzers_async(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> List[models.Analyzer]:
        r"""List of all available analyzers.

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if timeout_ms is None:
            timeout_ms = 60000

        if server_url is not None:
            base_url = server_url
        req = self.build_request_async(
            method="GET",
            path="/_acuvity/analyzers",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 60000, 1.5, 300000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "423", "429", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="get-all-Analyzers",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, List[models.Analyzer])
        if utils.match_response(http_res, ["400", "401", "500"], "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ElementalerrorData)
            raise models.Elementalerror(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def scan_request(
        self,
        *,
        request: Union[
            models.Scanrequest, models.ScanrequestTypedDict
        ] = models.Scanrequest(),
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> models.Scanresponse:
        r"""Processes the scan request.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if timeout_ms is None:
            timeout_ms = 60000

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.Scanrequest)
        request = cast(models.Scanrequest, request)

        req = self.build_request(
            method="POST",
            path="/_acuvity/scan",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, True, "json", Optional[models.Scanrequest]
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 60000, 1.5, 300000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "423", "429", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="create-ScanRequest-as-ScanResponse",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "422", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.Scanresponse)
        if utils.match_response(
            http_res, ["400", "403", "422", "500"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ElementalerrorData)
            raise models.Elementalerror(data=data)
        if utils.match_response(http_res, ["401", "429", "4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def scan_request_async(
        self,
        *,
        request: Union[
            models.Scanrequest, models.ScanrequestTypedDict
        ] = models.Scanrequest(),
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> models.Scanresponse:
        r"""Processes the scan request.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if timeout_ms is None:
            timeout_ms = 60000

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.Scanrequest)
        request = cast(models.Scanrequest, request)

        req = self.build_request_async(
            method="POST",
            path="/_acuvity/scan",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, True, "json", Optional[models.Scanrequest]
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 60000, 1.5, 300000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "423", "429", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="create-ScanRequest-as-ScanResponse",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "422", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.Scanresponse)
        if utils.match_response(
            http_res, ["400", "403", "422", "500"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ElementalerrorData)
            raise models.Elementalerror(data=data)
        if utils.match_response(http_res, ["401", "429", "4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .httpclient import AsyncHttpClient, HttpClient
from .sdkconfiguration import SDKConfiguration
from .utils.logger import Logger, get_default_logger
from .utils.retries import RetryConfig
from acuvity import models, utils
from acuvity._hooks import SDKHooks
from acuvity.apex import Apex
from acuvity.types import OptionalNullable, UNSET
import httpx
from typing import Callable, Dict, List, Optional, Union


class Acuvity(BaseSDK):
    r"""Apex API: Acuvity Apex provides access to scan and detection APIs"""

    apex: Apex
    r"""Apex is the proxy and detectiono API service of Acuvity."""

    def __init__(
        self,
        security: Optional[
            Union[models.Security, Callable[[], models.Security]]
        ] = None,
        apex_domain: Optional[str] = None,
        apex_port: Optional[str] = None,
        server_idx: Optional[int] = None,
        server_url: Optional[str] = None,
        url_params: Optional[Dict[str, str]] = None,
        client: Optional[HttpClient] = None,
        async_client: Optional[AsyncHttpClient] = None,
        retry_config: OptionalNullable[RetryConfig] = UNSET,
        timeout_ms: Optional[int] = None,
        debug_logger: Optional[Logger] = None,
    ) -> None:
        r"""Instantiates the SDK configuring it with the provided parameters.

        :param security: The security details required for authentication
        :param apex_domain: Allows setting the apex_domain variable for url substitution
        :param apex_port: Allows setting the apex_port variable for url substitution
        :param server_idx: The index of the server to use for all methods
        :param server_url: The server URL to use for all methods
        :param url_params: Parameters to optionally template the server URL with
        :param client: The HTTP client to use for all synchronous methods
        :param async_client: The Async HTTP client to use for all asynchronous methods
        :param retry_config: The retry configuration to use for all supported methods
        :param timeout_ms: Optional request timeout applied to each operation in milliseconds
        """
        if client is None:
            client = httpx.Client()

        assert issubclass(
            type(client), HttpClient
        ), "The provided client must implement the HttpClient protocol."

        if async_client is None:
            async_client = httpx.AsyncClient()

        if debug_logger is None:
            debug_logger = get_default_logger()

        assert issubclass(
            type(async_client), AsyncHttpClient
        ), "The provided async_client must implement the AsyncHttpClient protocol."

        if server_url is not None:
            if url_params is not None:
                server_url = utils.template_url(server_url, url_params)
        server_defaults: List[Dict[str, str]] = [
            {
                "apex_domain": apex_domain or "apex.acuvity.ai",
                "apex_port": apex_port or "443",
            },
        ]

        BaseSDK.__init__(
            self,
            SDKConfiguration(
                client=client,
                async_client=async_client,
                security=security,
                server_url=server_url,
                server_idx=server_idx,
                server_defaults=server_defaults,
                retry_config=retry_config,
                timeout_ms=timeout_ms,
                debug_logger=debug_logger,
            ),
        )

        hooks = SDKHooks()

        current_server_url, *_ = self.sdk_configuration.get_server_details()
        server_url, self.sdk_configuration.client = hooks.sdk_init(
            current_server_url, self.sdk_configuration.client
        )
        if current_server_url != server_url:
            self.sdk_configuration.server_url = server_url

        # pylint: disable=protected-access
        self.sdk_configuration.__dict__["_hooks"] = hooks

        self._init_sdks()

    def _init_sdks(self):
        self.apex = Apex(self.sdk_configuration)

    def __enter__(self):
        return self

    async def __aenter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        if self.sdk_configuration.client is not None:
            self.sdk_configuration.client.close()

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        if self.sdk_configuration.async_client is not None:
            await self.sdk_configuration.async_client.aclose()



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from acuvity.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ScanexternaluserTypedDict(TypedDict):
    r"""ScanExternalUser holds the information about the remote user for a ScanRequest."""

    claims: List[str]
    r"""List of claims extracted from the user query."""
    name: str
    r"""The name of the external user."""


class Scanexternaluser(BaseModel):
    r"""ScanExternalUser holds the information about the remote user for a ScanRequest."""

    claims: List[str]
    r"""List of claims extracted from the user query."""

    name: str
    r"""The name of the external user."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from acuvity import utils
from acuvity.types import BaseModel
from typing import Optional
from typing_extensions import TypedDict


class DataTypedDict(TypedDict):
    r"""Additional error data"""


class Data(BaseModel):
    r"""Additional error data"""


class ElementalerrorData(BaseModel):
    code: Optional[int] = None
    r"""Error code"""

    data: Optional[Data] = None
    r"""Additional error data"""

    description: Optional[str] = None
    r"""Error description"""

    subject: Optional[str] = None
    r"""Error subject"""

    title: Optional[str] = None
    r"""Error title"""

    trace: Optional[str] = None
    r"""Error trace"""


class Elementalerror(Exception):
    data: ElementalerrorData

    def __init__(self, data: ElementalerrorData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, ElementalerrorData)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from acuvity.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AnalyzermodelTypedDict(TypedDict):
    r"""Represent an analyzer model."""

    name: NotRequired[str]
    r"""The name of the model."""
    revision: NotRequired[str]
    r"""The revision of the model."""


class Analyzermodel(BaseModel):
    r"""Represent an analyzer model."""

    name: Optional[str] = None
    r"""The name of the model."""

    revision: Optional[str] = None
    r"""The revision of the model."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .alertevent import Alertevent, AlerteventTypedDict
from .analyzer import Analyzer, AnalyzerTypedDict
from .analyzermodel import Analyzermodel, AnalyzermodelTypedDict
from .apierror import APIError
from .detector import Detector, DetectorTypedDict
from .elementalerror import Data, DataTypedDict, Elementalerror, ElementalerrorData
from .extraction import Extraction, ExtractionTypedDict
from .extractionrequest import Extractionrequest, ExtractionrequestTypedDict
from .latency import Latency, LatencyTypedDict
from .modality import Modality, ModalityTypedDict
from .principal import AuthType, Principal, PrincipalType, PrincipalTypedDict
from .principalapp import Principalapp, PrincipalappTypedDict
from .principaluser import Principaluser, PrincipaluserTypedDict
from .scanexternaluser import Scanexternaluser, ScanexternaluserTypedDict
from .scanrequest import Anonymization, Scanrequest, ScanrequestTypedDict, Type
from .scanresponse import (
    Decision,
    Scanresponse,
    ScanresponseType,
    ScanresponseTypedDict,
)
from .security import Security, SecurityTypedDict
from .textualdetection import (
    Textualdetection,
    TextualdetectionType,
    TextualdetectionTypedDict,
)

__all__ = [
    "APIError",
    "Alertevent",
    "AlerteventTypedDict",
    "Analyzer",
    "AnalyzerTypedDict",
    "Analyzermodel",
    "AnalyzermodelTypedDict",
    "Anonymization",
    "AuthType",
    "Data",
    "DataTypedDict",
    "Decision",
    "Detector",
    "DetectorTypedDict",
    "Elementalerror",
    "ElementalerrorData",
    "Extraction",
    "ExtractionTypedDict",
    "Extractionrequest",
    "ExtractionrequestTypedDict",
    "Latency",
    "LatencyTypedDict",
    "Modality",
    "ModalityTypedDict",
    "Principal",
    "PrincipalType",
    "PrincipalTypedDict",
    "Principalapp",
    "PrincipalappTypedDict",
    "Principaluser",
    "PrincipaluserTypedDict",
    "Scanexternaluser",
    "ScanexternaluserTypedDict",
    "Scanrequest",
    "ScanrequestTypedDict",
    "Scanresponse",
    "ScanresponseType",
    "ScanresponseTypedDict",
    "Security",
    "SecurityTypedDict",
    "Textualdetection",
    "TextualdetectionType",
    "TextualdetectionTypedDict",
    "Type",
]
